@@ -8,7 +8,6 @@ our @ISA = qw{ Module::Build };
 
 use Carp;
 
-
 sub ACTION_authortest {
     my ( $self, @args ) = @_;
 
@@ -70,8 +69,9 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Perl-Critic-Policy-RegularExpressions-ProhibitEmptyAlternatives/issues>,
-or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Critic-Policy-RegularExpressions-ProhibitEmptyAlternatives>,
+L<https://github.com/trwyant/perl-Perl-Critic-Policy-RegularExpressions-ProhibitEmptyAlternatives/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
